==> apache-pulsar-2.8.3-src.tar.gz: apache-pulsar-2.8.3-src/pulsar-client/src/main/java/org/apache/pulsar/client/impl/auth/AuthenticationDataKeyStoreTls.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.impl.auth;

import lombok.extern.slf4j.Slf4j;
import org.apache.pulsar.client.api.AuthenticationDataProvider;
import org.apache.pulsar.client.api.KeyStoreParams;

@Slf4j
public class AuthenticationDataKeyStoreTls implements AuthenticationDataProvider {

    private static final long serialVersionUID = 1L;
    private transient final KeyStoreParams keyStoreParams;

    public AuthenticationDataKeyStoreTls(KeyStoreParams keyStoreParams) throws Exception {
        this.keyStoreParams = keyStoreParams;
    }

    /*
     * TLS
     */
    @Override
    public boolean hasDataForTls() {
        return true;
    }

    @Override
    public KeyStoreParams getTlsKeyStoreParams() {
        return this.keyStoreParams;
    }

    @Override
    public String getCommandData() {
        return null;
    }
}

==> apache-pulsar-2.11.1-src.tar.gz: apache-pulsar-2.11.1-src/pulsar-client/src/main/java/org/apache/pulsar/client/impl/auth/AuthenticationDataKeyStoreTls.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.impl.auth;

import lombok.extern.slf4j.Slf4j;
import org.apache.pulsar.client.api.AuthenticationDataProvider;
import org.apache.pulsar.client.api.KeyStoreParams;

@Slf4j
public class AuthenticationDataKeyStoreTls implements AuthenticationDataProvider {

    private static final long serialVersionUID = 1L;
    private final transient KeyStoreParams keyStoreParams;

    public AuthenticationDataKeyStoreTls(KeyStoreParams keyStoreParams) throws Exception {
        this.keyStoreParams = keyStoreParams;
    }

    /*
     * TLS
     */
    @Override
    public boolean hasDataForTls() {
        return true;
    }

    @Override
    public KeyStoreParams getTlsKeyStoreParams() {
        return this.keyStoreParams;
    }

    @Override
    public String getCommandData() {
        return null;
    }
}
